@@ -3,7 +3,7 @@
 #' @description \code{diagnostic} checks the convergence of MCMC for LSIRM parameters using various diagnostic tools, such as trace plots, posterior density distributions, autocorrelation functions (ACF), and Gelman-Rubin-Brooks plots.
 #'
 #' @param object Object of class \code{lsirm}.
-#' @param draw.item List; Each key in the list corresponds to a specific parameters such as "beta", "theta", "gamma", "alpha", "theta_sd", "sigma" and "zw.dist". The values of the list indicate the indices of these parameters. For the key "zw.dist", the value is a matrix with two columns: the first column represents the indices of respondents, and the second column represents the indices of items.
+#' @param draw.item List; Each key in the list corresponds to a specific parameters such as "beta", "theta", "gamma", "alpha", "sigma", "theta_sd", "z", "w", and "zw.dist". The values of the list indicate the indices of these parameters. For the key "zw.dist", the value is a matrix with two columns: the first column represents the indices of respondents, and the second column represents the indices of items. For the keys "z" and "w", the value is a matrix with two columns: the first column represents the indices of respondents/items, and the second column represents the dimension indices.
 #' @param gelman.diag Logical; If TRUE, the Gelman-Rubin convergence diagnostic will be printed. Default is FALSE.
 #'
 #' @return \code{diagnostic} returns plots for checking MCMC convergence for selected parameters.
@@ -21,6 +21,10 @@
 #' lsirm_result <- lsirm(data ~ lsirm2pl(spikenslab = FALSE, fixed_gamma = FALSE))
 #' diagnostic(lsirm_result)
 #'
+#' # For specific latent positions
+#' diagnostic(lsirm_result, draw.item = list(z = matrix(c(1,1, 2,1, 1,2), ncol=2, byrow=TRUE),
+#'                                        w = matrix(c(1,1, 2,1), ncol=2, byrow=TRUE)))
+#'
 #' }
 #' @export diagnostic
 diagnostic <- function(object,
@@ -38,8 +42,8 @@ diagnostic.lsirm <- function(object,
 {
 
   ACF <- Chain <- Iteration <- Lag <- PSRF <- Type <- iteration <- var1 <- NULL
-  orders = data.frame(idx = c(1:7),
-                      param = c("beta", "theta", "gamma", "alpha", "sigma", "theta_sd", "zw.dist"))
+  orders = data.frame(idx = c(1:9),
+                      param = c("beta", "theta", "gamma", "alpha", "sigma", "theta_sd", "z", "w", "zw.dist"))
   which.draw = names(draw.item)
   porder = orders[orders$param %in% which.draw,]
 
@@ -71,7 +75,9 @@ diagnostic.lsirm <- function(object,
 
   if(is.null(draw.item$beta)&("beta" %in% which.draw)) draw.item$beta = "first"
   if(is.null(draw.item$theta)&("theta" %in% which.draw)) draw.item$theta = "first"
-  if(is.null(draw.item$alpha)&("alpha" %in% which.draw)) draw.item$alpha = "second"
+  if(is.null(draw.item$alpha)&("alpha" %in% which.draw)) draw.item$alpha = 2
+  if(is.null(draw.item$z)&("z" %in% which.draw)) draw.item$z = matrix(c(1, 1), ncol = 2)
+  if(is.null(draw.item$w)&("w" %in% which.draw)) draw.item$w = matrix(c(1, 1), ncol = 2)
   if(is.null(draw.item$zw.dist)&("zw.dist" %in% which.draw)) draw.item$zw.dist = matrix(c(1, 1), ncol = 2)
   chain_list_all <- vector("list", length = object$chains)
 
@@ -186,23 +192,12 @@ diagnostic.lsirm <- function(object,
           ylab("Autocorrelation") +
           theme(legend.position = "none")
 
-        # autocorrelation_plot <- ggplot(acf_combined,
-        #                                aes(x = Lag, y = ACF,
-        #                                    color = factor(Chain), group = Chain)) +
-        #   geom_hline(aes(yintercept = 0)) +
-        #   geom_segment(mapping = aes(xend = Lag, yend = 0)) +
-        #   xlab("Lag") +
-        #   ylab("Autocorrelation") +
-        #   theme(legend.position = "none")
-
         pdf(file = NULL)
         # Call gelman.plot
         gelman_plot <- gelman.plot(chain_data)
         # Close the null device
         dev.off()
 
-
-
         median_values <- gelman_plot$shrink[,, "median"]
         upper_values <- gelman_plot$shrink[,, "97.5%"]
         iterations <- gelman_plot$last.iter
@@ -242,7 +237,7 @@ diagnostic.lsirm <- function(object,
                                                   ncol = 2))
 
         if(porder[porder$param == "beta",]$idx == max(porder$idx)){
-          if(((length(draw.item.num) > 1)&(i < length(draw.item.num))) | !is.null(which.draw.temp) ){
+          if(((length(draw.item.num) > 1)&(i < length(draw.item.num))) ){
             readline(prompt = "Hit <Return> to see next plot")
           }
         }else{
@@ -314,13 +309,10 @@ diagnostic.lsirm <- function(object,
 
     if(multi_chain){
 
-
       if(is.null(rownames(object[[1]]$data))){
         colnames(object[[1]]$theta) = 1:ncol(object[[1]]$theta)
       }else{colnames(object[[1]]$theta) <- rownames(object[[1]]$data)}
 
-
-
       if((length(draw.item$theta) == 1) & (draw.item$theta[1] == "first")){
         draw.item.temp = colnames(object[[1]]$theta)[1]
         draw.item.num <- 1
@@ -332,7 +324,6 @@ diagnostic.lsirm <- function(object,
         draw.item.num = which(colnames(object[[1]]$theta) %in% draw.item.temp)
       }
 
-
       pnames <- c(paste('theta [', draw.item.temp, ']', sep = ''))
       chains <- object$chains
 
@@ -351,8 +342,6 @@ diagnostic.lsirm <- function(object,
         colnames(object$theta) = 1:ncol(object$theta)
       }else{colnames(object$theta) <- rownames(object$data)}
 
-
-
       if((length(draw.item$theta) == 1) & (draw.item$theta[1] == "first")){
         draw.item.temp = colnames(object$theta)[1]
         draw.item.num <- 1
@@ -364,7 +353,6 @@ diagnostic.lsirm <- function(object,
         draw.item.num = which(colnames(object$theta) %in% draw.item.temp)
       }
 
-
       pnames <- c(paste('theta [', draw.item.temp, ']', sep = ''))
       chains <- 1
 
@@ -738,9 +726,22 @@ diagnostic.lsirm <- function(object,
   if("alpha" %in% which.draw){
 
     if(multi_chain){
+      if(is.null(colnames(object[[1]]$data))){
+        colnames(object[[1]]$alpha) = 1:ncol(object[[1]]$alpha)
+      }else{colnames(object[[1]]$alpha) <- colnames(object[[1]]$data)}
 
-      draw.item.num <- 1
-      pnames <- c(paste('alpha', sep = ''))
+      if((length(draw.item$alpha) == 1) & (draw.item$alpha[1] == "first")){
+        draw.item.temp = colnames(object[[1]]$alpha)[1]
+        draw.item.num <- 1
+      }else if(is.numeric(draw.item$alpha)){
+        draw.item.temp = colnames(object[[1]]$alpha)[draw.item$alpha]
+        draw.item.num <- draw.item$alpha
+      }else{
+        draw.item.temp = draw.item$alpha
+        draw.item.num = which(colnames(object[[1]]$alpha) %in% draw.item.temp)
+      }
+
+      pnames <- c(paste('alpha [', draw.item.temp, ']', sep = ''))
       chains <- object$chains
 
       chain_list <- list()
@@ -754,10 +755,22 @@ diagnostic.lsirm <- function(object,
         }
       }
     }else{
+      if(is.null(colnames(object$data))){
+        colnames(object$alpha) = 1:ncol(object$alpha)
+      }else{colnames(object$alpha) <- colnames(object$data)}
 
+      if((length(draw.item$alpha) == 1) & (draw.item$alpha[1] == "first")){
+        draw.item.temp = colnames(object$alpha)[1]
+        draw.item.num <- 1
+      }else if(is.numeric(draw.item$alpha)){
+        draw.item.temp = colnames(object$alpha)[draw.item$alpha]
+        draw.item.num <- draw.item$alpha
+      }else{
+        draw.item.temp = draw.item$alpha
+        draw.item.num = which(colnames(object$alpha) %in% draw.item.temp)
+      }
 
-      draw.item.num <- 1
-      pnames <- c(paste('alpha', sep = ''))
+      pnames <- c(paste('alpha [', draw.item.temp, ']', sep = ''))
       chains <- 1
 
       chain_list <- list()
@@ -813,14 +826,6 @@ diagnostic.lsirm <- function(object,
           geom_hline(aes(yintercept = (exp(2*1.96/sqrt(nmcmc-3)-1)/(exp(2*1.96/sqrt(nmcmc-3)+1)))), linetype='dotted', col = 'blue') +
           ylab("Autocorrelation") +
           theme(legend.position = "none")
-        # autocorrelation_plot <- ggplot(acf_combined,
-        #                                aes(x = Lag, y = ACF,
-        #                                    color = factor(Chain), group = Chain)) +
-        #   geom_hline(aes(yintercept = 0)) +
-        #   geom_segment(mapping = aes(xend = Lag, yend = 0)) +
-        #   xlab("Lag") +
-        #   ylab("Autocorrelation") +
-        #   theme(legend.position = "none")
 
         pdf(file = NULL)
         # Call gelman.plot
@@ -1545,6 +1550,364 @@ diagnostic.lsirm <- function(object,
     which.draw.temp <- setdiff(which.draw.temp, c("zw.dist"))
   } ## Dist
 
+  ## z ---------
+  if("z" %in% which.draw){
+
+    if(multi_chain){
+
+      draw.item.temp <- apply(draw.item$z, 1, function(row) paste(row, collapse = "-"))
+      draw.item.num <- length(draw.item.temp)
+
+      pnames <- c(paste('z [', draw.item.temp, ']', sep = ''))
+      chains <- object$chains
+
+      chain_list <- list()
+      nmcmc <- dim(object[[1]]$z)[1]
+
+      for(i in 1:chains){
+        z_temp <- matrix(0, nrow = nmcmc, ncol = nrow(draw.item$z))
+                  for(j in 1:nrow(draw.item$z)){
+
+            iz = draw.item$z[j,1]
+            idim = draw.item$z[j,2]
+
+            z_temp[,j] <- object[[i]]$z[,iz,idim]
+          }
+        chain_list[[i]] <- matrix(z_temp, ncol = length(pnames),
+                                  dimnames= list(NULL,pnames))
+        if(length(chain_list_all[[i]]) == 0){
+          chain_list_all[[i]] <- chain_list[[i]]
+        }else{
+          chain_list_all[[i]] <- cbind(chain_list_all[[i]], chain_list[[i]])
+        }
+      }
+    }else{
+
+      draw.item.temp <- apply(draw.item$z, 1, function(row) paste(row, collapse = "-"))
+      draw.item.num <- length(draw.item.temp)
+
+      pnames <- c(paste('z [', draw.item.temp, ']', sep = ''))
+
+      chain_list <- list()
+      nmcmc <- dim(object$z)[1]
+
+      z_temp <- matrix(0, nrow = nmcmc, ncol = nrow(draw.item$z))
+
+      for(j in 1:nrow(draw.item$z)){
+
+        iz = draw.item$z[j,1]
+        idim = draw.item$z[j,2]
+
+        z_temp[,j] <- object$z[,iz,idim]
+
+      }
+      chain_list[[1]] <- matrix(z_temp, ncol = length(pnames),
+                                dimnames= list(NULL,pnames))
+
+
+    }
+
+    mcmc_chains <- lapply(chain_list, function(x) coda::mcmc(x, thin = 1))
+    mcmclist <- coda::as.mcmc.list(mcmc_chains)
+    params <- dimnames(mcmclist[[1]])[[2]]
+
+    plots_list <- list()
+
+    for(i in 1:draw.item.num){
+      param <- colnames(mcmclist[[1]])[i]
+      chain_data <- lapply(mcmclist, function(chain) chain[, param])
+
+      combined_data <- do.call(rbind, lapply(seq_along(chain_data), function(j) {
+        data.frame(iteration = seq_along(chain_data[[j]]), value = chain_data[[j]], Chain = j)
+      }))
+
+      if(multi_chain){
+
+        trace_plot <- ggplot(combined_data, aes(x = iteration, y = var1, group = Chain, color = factor(Chain))) +
+          geom_line() +
+          xlab("Iterations") +
+          ylab("Value") + theme(legend.position = "none")
+
+        density_plot <- ggplot(combined_data, aes(x = var1, fill = factor(Chain), color = factor(Chain))) +
+          geom_density(alpha = 0.1) +
+          xlab("Value") +
+          ylab("Density") +
+          theme(legend.position = "none")
+
+        autocorrelation_plots <- lapply(seq_along(chain_data), function(j) {
+          acf_data <- acf(chain_data[[j]], plot = FALSE, lag.max = 60)
+          data.frame(Lag = acf_data$lag, ACF = acf_data$acf, Chain = j)
+        })
+
+        acf_combined <- do.call(rbind, autocorrelation_plots)
+        autocorrelation_plot <- ggplot(acf_combined, aes(x = Lag, y = ACF, color = factor(Chain), group = Chain)) +
+          geom_line() +
+          xlab("Lag") +
+          geom_hline(aes(yintercept = (exp(2*1.96/sqrt(nmcmc-3)-1)/(exp(2*1.96/sqrt(nmcmc-3)+1)))), linetype='dotted', col = 'blue') +
+          ylab("Autocorrelation") +
+          theme(legend.position = "none")
+
+        pdf(file = NULL)
+        gelman_plot <- gelman.plot(chain_data)
+        dev.off()
+
+        median_values <- gelman_plot$shrink[,, "median"]
+        upper_values <- gelman_plot$shrink[,, "97.5%"]
+        iterations <- gelman_plot$last.iter
+
+        psrf_data <- data.frame(
+          Iteration = iterations,
+          MedianPSRF = as.vector(median_values),
+          UpperPSRF = as.vector(upper_values)
+        )
+
+        psrf_long <- pivot_longer(psrf_data, cols = c("MedianPSRF", "UpperPSRF"), names_to = "Type", values_to = "PSRF") %>%
+          mutate(Type = recode(Type, "UpperPSRF" = "97.5%", "MedianPSRF" = "Median"))
+
+        psrf_plot <- ggplot(psrf_long, aes(x = Iteration, y = PSRF, group = Type)) +
+          geom_line(aes(linetype = Type, color = Type)) +
+          scale_linetype_manual(values = c("97.5%" = "dashed", "Median" = "solid")) +
+          scale_color_manual(values = c("97.5%" = "#377EB8", "Median" = "#E41A1C")) +
+          labs(title = "", x = "Last Iteration in chain", y = "Shrink Factor") +
+          theme_minimal() +
+          theme(legend.title = element_blank(),
+                legend.position = c(1, 1),
+                legend.justification = c("right", "top")
+          )
+
+        combined_plot <- grid.arrange(arrangeGrob(trace_plot,
+                                                  density_plot,
+                                                  autocorrelation_plot,
+                                                  psrf_plot,
+                                                  top = textGrob(param, vjust = 1, gp = gpar(fontface = "bold", cex = 1)),
+                                                  ncol = 2))
+
+        if((draw.item.num > 1)&(i < draw.item.num)){
+          readline(prompt = "Hit <Return> to see next plot")
+        }
+      }else{
+
+        trace_plot <- ggplot(combined_data, aes(x = iteration, y = var1, group = Chain, color = factor(Chain))) +
+          geom_line(color = "#268bd2") +
+          xlab("Iterations") +
+          ylab("Value") + theme(legend.position = "none")
+
+        density_plot <- ggplot(combined_data, aes(x = var1)) +
+          geom_density(color = "#268bd2", fill = "#268bd2", alpha = 0.1) +
+          xlab("Value") +
+          ylab("Density") +
+          theme(legend.position = "none")
+
+        autocorrelation_plots <- lapply(seq_along(chain_data), function(j) {
+          acf_data <- acf(chain_data[[j]], plot = FALSE, lag.max = 60)
+          data.frame(Lag = acf_data$lag, ACF = acf_data$acf, Chain = j)
+        })
+
+        acf_combined <- do.call(rbind, autocorrelation_plots)
+        autocorrelation_plot <- ggplot(acf_combined,
+                                       aes(x = Lag, y = ACF,
+                                           color = factor(Chain), group = Chain)) +
+          geom_hline(aes(yintercept = 0)) +
+          geom_segment(mapping = aes(xend = Lag, yend = 0)) +
+          xlab("Lag") +
+          geom_hline(aes(yintercept = (exp(2*1.96/sqrt(nmcmc-3)-1)/(exp(2*1.96/sqrt(nmcmc-3)+1)))), linetype='dotted', col = 'blue') +
+          ylab("Autocorrelation") +
+          theme(legend.position = "none")
+
+        combined_plot <- grid.arrange(arrangeGrob(trace_plot,
+                                                  density_plot,
+                                                  autocorrelation_plot,
+                                                  top = textGrob(param, vjust = 1, gp = gpar(fontface = "bold", cex = 1)),
+                                                  ncol = 2))
+
+        if((draw.item.num > 1)&(i < draw.item.num)){
+          readline(prompt = "Hit <Return> to see next plot")
+        }
+      }
+    }
+
+    which.draw.temp <- setdiff(which.draw.temp, c("z"))
+  } ## z
+
+  ## w ---------
+  if("w" %in% which.draw){
+
+    if(multi_chain){
+
+      draw.item.temp <- apply(draw.item$w, 1, function(row) paste(row, collapse = "-"))
+      draw.item.num <- length(draw.item.temp)
+
+      pnames <- c(paste('w [', draw.item.temp, ']', sep = ''))
+      chains <- object$chains
+
+      chain_list <- list()
+      nmcmc <- dim(object[[1]]$w)[1]
+
+      for(i in 1:chains){
+        w_temp <- matrix(0, nrow = nmcmc, ncol = nrow(draw.item$w))
+                  for(j in 1:nrow(draw.item$w)){
+
+            iw = draw.item$w[j,1]
+            idim = draw.item$w[j,2]
+
+            w_temp[,j] <- object[[i]]$w[,iw,idim]
+          }
+        chain_list[[i]] <- matrix(w_temp, ncol = length(pnames),
+                                  dimnames= list(NULL,pnames))
+        if(length(chain_list_all[[i]]) == 0){
+          chain_list_all[[i]] <- chain_list[[i]]
+        }else{
+          chain_list_all[[i]] <- cbind(chain_list_all[[i]], chain_list[[i]])
+        }
+      }
+    }else{
+
+      draw.item.temp <- apply(draw.item$w, 1, function(row) paste(row, collapse = "-"))
+      draw.item.num <- nrow(draw.item$w)
+
+      pnames <- c(paste('w [', draw.item.temp, ']', sep = ''))
+
+      chain_list <- list()
+      nmcmc <- dim(object$w)[1]
+
+      w_temp <- matrix(0, nrow = nmcmc, ncol = nrow(draw.item$w))
+
+      for(j in 1:nrow(draw.item$w)){
+
+        iw = draw.item$w[j,1]
+        idim = draw.item$w[j,2]
+
+        w_temp[,j] <- object$w[,iw,idim]
+
+      }
+      chain_list[[1]] <- matrix(w_temp, ncol = length(pnames),
+                                dimnames= list(NULL,pnames))
+
+
+    }
+
+    mcmc_chains <- lapply(chain_list, function(x) coda::mcmc(x, thin = 1))
+    mcmclist <- coda::as.mcmc.list(mcmc_chains)
+    params <- dimnames(mcmclist[[1]])[[2]]
+
+    plots_list <- list()
+
+    for(i in 1:draw.item.num){
+      param <- colnames(mcmclist[[1]])[i]
+      chain_data <- lapply(mcmclist, function(chain) chain[, param])
+
+      combined_data <- do.call(rbind, lapply(seq_along(chain_data), function(j) {
+        data.frame(iteration = seq_along(chain_data[[j]]), value = chain_data[[j]], Chain = j)
+      }))
+
+      if(multi_chain){
+
+        trace_plot <- ggplot(combined_data, aes(x = iteration, y = var1, group = Chain, color = factor(Chain))) +
+          geom_line() +
+          xlab("Iterations") +
+          ylab("Value") + theme(legend.position = "none")
+
+        density_plot <- ggplot(combined_data, aes(x = var1, fill = factor(Chain), color = factor(Chain))) +
+          geom_density(alpha = 0.1) +
+          xlab("Value") +
+          ylab("Density") +
+          theme(legend.position = "none")
+
+        autocorrelation_plots <- lapply(seq_along(chain_data), function(j) {
+          acf_data <- acf(chain_data[[j]], plot = FALSE, lag.max = 60)
+          data.frame(Lag = acf_data$lag, ACF = acf_data$acf, Chain = j)
+        })
+
+        acf_combined <- do.call(rbind, autocorrelation_plots)
+        autocorrelation_plot <- ggplot(acf_combined, aes(x = Lag, y = ACF, color = factor(Chain), group = Chain)) +
+          geom_line() +
+          xlab("Lag") +
+          geom_hline(aes(yintercept = (exp(2*1.96/sqrt(nmcmc-3)-1)/(exp(2*1.96/sqrt(nmcmc-3)+1)))), linetype='dotted', col = 'blue') +
+          ylab("Autocorrelation") +
+          theme(legend.position = "none")
+
+        pdf(file = NULL)
+        gelman_plot <- gelman.plot(chain_data)
+        dev.off()
+
+        median_values <- gelman_plot$shrink[,, "median"]
+        upper_values <- gelman_plot$shrink[,, "97.5%"]
+        iterations <- gelman_plot$last.iter
+
+        psrf_data <- data.frame(
+          Iteration = iterations,
+          MedianPSRF = as.vector(median_values),
+          UpperPSRF = as.vector(upper_values)
+        )
+
+        psrf_long <- pivot_longer(psrf_data, cols = c("MedianPSRF", "UpperPSRF"), names_to = "Type", values_to = "PSRF") %>%
+          mutate(Type = recode(Type, "UpperPSRF" = "97.5%", "MedianPSRF" = "Median"))
+
+        psrf_plot <- ggplot(psrf_long, aes(x = Iteration, y = PSRF, group = Type)) +
+          geom_line(aes(linetype = Type, color = Type)) +
+          scale_linetype_manual(values = c("97.5%" = "dashed", "Median" = "solid")) +
+          scale_color_manual(values = c("97.5%" = "#377EB8", "Median" = "#E41A1C")) +
+          labs(title = "", x = "Last Iteration in chain", y = "Shrink Factor") +
+          theme_minimal() +
+          theme(legend.title = element_blank(),
+                legend.position = c(1, 1),
+                legend.justification = c("right", "top")
+          )
+
+        combined_plot <- grid.arrange(arrangeGrob(trace_plot,
+                                                  density_plot,
+                                                  autocorrelation_plot,
+                                                  psrf_plot,
+                                                  top = textGrob(param, vjust = 1, gp = gpar(fontface = "bold", cex = 1)),
+                                                  ncol = 2))
+
+        if((draw.item.num > 1)&(i < draw.item.num)){
+          readline(prompt = "Hit <Return> to see next plot")
+        }
+      }else{
+
+        trace_plot <- ggplot(combined_data, aes(x = iteration, y = var1, group = Chain, color = factor(Chain))) +
+          geom_line(color = "#268bd2") +
+          xlab("Iterations") +
+          ylab("Value") + theme(legend.position = "none")
+
+        density_plot <- ggplot(combined_data, aes(x = var1)) +
+          geom_density(color = "#268bd2", fill = "#268bd2", alpha = 0.1) +
+          xlab("Value") +
+          ylab("Density") +
+          theme(legend.position = "none")
+
+        autocorrelation_plots <- lapply(seq_along(chain_data), function(j) {
+          acf_data <- acf(chain_data[[j]], plot = FALSE, lag.max = 60)
+          data.frame(Lag = acf_data$lag, ACF = acf_data$acf, Chain = j)
+        })
+
+        acf_combined <- do.call(rbind, autocorrelation_plots)
+        autocorrelation_plot <- ggplot(acf_combined,
+                                       aes(x = Lag, y = ACF,
+                                           color = factor(Chain), group = Chain)) +
+          geom_hline(aes(yintercept = 0)) +
+          geom_segment(mapping = aes(xend = Lag, yend = 0)) +
+          xlab("Lag") +
+          geom_hline(aes(yintercept = (exp(2*1.96/sqrt(nmcmc-3)-1)/(exp(2*1.96/sqrt(nmcmc-3)+1)))), linetype='dotted', col = 'blue') +
+          ylab("Autocorrelation") +
+          theme(legend.position = "none")
+
+        combined_plot <- grid.arrange(arrangeGrob(trace_plot,
+                                                  density_plot,
+                                                  autocorrelation_plot,
+                                                  top = textGrob(param, vjust = 1, gp = gpar(fontface = "bold", cex = 1)),
+                                                  ncol = 2))
+
+        if((draw.item.num > 1)&(i < draw.item.num)){
+          readline(prompt = "Hit <Return> to see next plot")
+        }
+      }
+    }
+
+    which.draw.temp <- setdiff(which.draw.temp, c("w"))
+  } ## w
+
   if(gelman.diag == TRUE){
     if(object$chains > 1){
       # mcmc_chains <- lapply(chain_list, coda::mcmc, thin = 1)
