@@ -117,7 +117,7 @@ cat("\n")
   # cat("\n\nCalculate BIC\n")
   log_like = log_likelihood_normal2pl_cpp(as.matrix(data), ndim, as.matrix(beta.estimate), as.matrix(alpha.estimate), as.matrix(theta.estimate), 1, z.est, w.est, sigma.estimate, 99)
   p = 2 * nitem + nsample + 1 + ndim * nitem + ndim * nsample + 1
-  bic = -2 * log_like[[1]] + p * log(nsample * nsample)
+  bic = -2 * log_like[[1]] + p * log(nitem * nsample)
 
   result <- list(data = data,
               bic = bic,
